@@ -25,4 +25,7 @@ class ApiStub(Stub):
         self._send('get-all-companies', {})
         
     def live_prediction(self, content):
-        self._send('live-prediction', {})
\ No newline at end of file
+        self._send('live-prediction', content)
+        
+    def live_prediction_movement(self, content):
+        self._send('live-prediction-movement', content)
\ No newline at end of file
