@@ -63,7 +63,7 @@ class RabbitMQServer(object):
             traceback.print_exc()
 
     def _binary_to_dict(self, binary_json):
-        return loads(binary_json, encoding='utf-8')
+        return literal_eval(binary_json.decode('utf-8'))
 
     def _handle_message(self, message: dict):
         if self._message_handlers and message['primitive'] in self._message_handlers:
